import { Modal } from 'antd';
import { create } from 'zustand';
import { generateQRCode } from '../../../uitls/qrcode';
import { useEffect, useState } from 'react';
import { queryApi } from '../store';
import { toast } from 'react-toastify';

interface PayModalStore {
  open: boolean;
  setOpen: (open: boolean) => void;
  money: number;
  setMoney: (money: number) => void;
  level: string;
  setLevel: (level: string) => void;
}
export const usePayModalStore = create<PayModalStore>((set) => ({
  open: false,
  setOpen: (open: boolean) => set({ open }),
  money: 0,
  setMoney: (money: number) => set({ money }),
  level: 'money',
  setLevel: (level: string) => set({ level }),
}));

export const PayModal = () => {
  const { open, setOpen, money, level } = usePayModalStore();
  const [wxQrCode, setWxQrCode] = useState('');
  const [wxIframeURL, setWxIframeURL] = useState('');
  const [alipayIframeURL, setAlipayIframeURL] = useState('');
  const [payMode, setPayMode] = useState<'wx' | 'alipay' | 'unset'>('unset');
  useEffect(() => {
    initQrCode(wxIframeURL);
  }, [wxIframeURL]);
  const initQrCode = async (url: string) => {
    if (!url) return;
    const wxQrCode = await generateQRCode(url);
    setWxQrCode(wxQrCode);
  };
  const onPay = async (payMode: 'wx' | 'alipay') => {
    const res = await queryApi.vipPay({
      level,
      money: money * 100,
      payMode,
    });
    if (res.code === 200) {
      if (payMode === 'wx') {
        const form = res.data.url;
        const wxQrCode = await generateQRCode(form);
        setWxQrCode(wxQrCode);
      } else {
        const form = res.data.form;
        setAlipayIframeURL(form);
      }
    } else {
      toast.error(res.message || '支付失败');
    }
  };

  return (
    <Modal open={open} onCancel={() => setOpen(false)} maskClosable={false} footer={null} style={{}}>
      <div className='px-4 py-4 flex flex-col gap-4 select-none justify-center items-center'>
        <h2 className='text-2xl font-bold mb-4'>支付确认</h2>
        <p className='text-lg'>请确认支付金额：{money} 元</p>
        {payMode === 'wx' && wxQrCode && <img className='w-[210px] h-[210px] ' src={wxQrCode} alt='微信支付' />}
        {payMode === 'alipay' && alipayIframeURL && <iframe src={alipayIframeURL} className='w-[210px] h-[210px]' />}
        <div className='flex gap-2'>
          <button
            className='bg-blue-500 text-white px-4 py-2 rounded-md hover:bg-blue-600 cursor-pointer'
            onClick={() => {
              setPayMode('wx');
              onPay('wx');
            }}>
            微信支付
          </button>
          <button
            className='bg-blue-500 text-white px-4 py-2 rounded-md hover:bg-blue-600 cursor-pointer'
            onClick={() => {
              setPayMode('alipay');
              onPay('alipay');
            }}>
            支付宝支付
          </button>
        </div>
      </div>
    </Modal>
  );
};
